@@ -283,11 +283,21 @@ static gboolean
 glade_design_view_draw (GtkWidget *widget, cairo_t *cr)
 {
   GladeDesignViewPrivate *priv = GLADE_DESIGN_VIEW_GET_PRIVATE (widget);
-  
-  GTK_WIDGET_CLASS (glade_design_view_parent_class)->draw (widget, cr);
+  GdkWindow *window = gtk_widget_get_window (widget);
 
-  if (gtk_widget_get_visible (priv->scrolled_window) == FALSE)
-    logo_draw (widget, cr);
+  if (gtk_cairo_should_draw_window (cr, window))
+    {
+      if (gtk_widget_get_visible (priv->scrolled_window) == FALSE)
+        logo_draw (widget, cr);
+      else
+        gtk_render_background (gtk_widget_get_style_context (widget),
+                               cr,
+                               0, 0,
+                               gdk_window_get_width (window),
+                               gdk_window_get_height (window));
+    }
+
+  GTK_WIDGET_CLASS (glade_design_view_parent_class)->draw (widget, cr);
   
   return FALSE;
 }
@@ -295,7 +305,6 @@ glade_design_view_draw (GtkWidget *widget, cairo_t *cr)
 static void
 glade_design_view_init (GladeDesignView *view)
 {
-  GtkCssProvider *provider;
   GtkWidget *viewport;
 
   view->priv = GLADE_DESIGN_VIEW_GET_PRIVATE (view);
@@ -329,15 +338,8 @@ glade_design_view_init (GladeDesignView *view)
   
   gtk_container_set_border_width (GTK_CONTAINER (view), 0);
 
-  provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_data (provider,
-                                   "GtkViewport {\n"
-                                   "  background-color : @base_color;\n"
-                                   "  }", -1, NULL);
-
-  gtk_style_context_add_provider (gtk_widget_get_style_context (GTK_WIDGET (viewport)),
-                                  GTK_STYLE_PROVIDER (provider),
-                                  GTK_STYLE_PROVIDER_PRIORITY_FALLBACK);
+  gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (view)),
+                               GTK_STYLE_CLASS_VIEW);
 }
 
 static void
